<?php
/**
 * VW Wedding Theme Customizer
 *
 * @package VW Wedding
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_wedding_custom_controls() {

    load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'vw_wedding_custom_controls' );

function vw_wedding_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_wedding_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-wedding' ),
	    'description' => __( 'Description of what this panel does.', 'vw-wedding' ),
	) );

	$wp_customize->add_section( 'vw_wedding_left_right', array(
    	'title'      => __( 'General Settings', 'vw-wedding' ),
		'priority'   => 30,
		'panel' => 'vw_wedding_panel_id'
	) );

	$wp_customize->add_setting('vw_wedding_width_option',array(
        'default' => __('Full Width','vw-wedding'),
        'sanitize_callback' => 'vw_wedding_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Wedding_Image_Radio_Control($wp_customize, 'vw_wedding_width_option', array(
        'type' => 'select',
        'label' => __('Width Layouts','vw-wedding'),
        'description' => __('Here you can change the width layout of Website.','vw-wedding'),
        'section' => 'vw_wedding_left_right',
        'choices' => array(
            'Full Width' => get_template_directory_uri().'/images/full-width.png',
            'Wide Width' => get_template_directory_uri().'/images/wide-width.png',
            'Boxed' => get_template_directory_uri().'/images/boxed-width.png',
    ))));

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_wedding_theme_options',array(
        'default' => __('Right Sidebar','vw-wedding'),
        'sanitize_callback' => 'vw_wedding_sanitize_choices'	        
	) );
	$wp_customize->add_control('vw_wedding_theme_options', array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','vw-wedding'),
        'description' => __('Here you can change the sidebar layout for posts. ','vw-wedding'),
        'section' => 'vw_wedding_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-wedding'),
            'Right Sidebar' => __('Right Sidebar','vw-wedding'),
            'One Column' => __('One Column','vw-wedding'),
            'Three Columns' => __('Three Columns','vw-wedding'),
            'Four Columns' => __('Four Columns','vw-wedding'),
            'Grid Layout' => __('Grid Layout','vw-wedding')
        ),
	));

	$wp_customize->add_setting('vw_wedding_page_layout',array(
        'default' => __('One Column','vw-wedding'),
        'sanitize_callback' => 'vw_wedding_sanitize_choices'
	));
	$wp_customize->add_control('vw_wedding_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','vw-wedding'),
        'description' => __('Here you can change the sidebar layout for pages. ','vw-wedding'),
        'section' => 'vw_wedding_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-wedding'),
            'Right Sidebar' => __('Right Sidebar','vw-wedding'),
            'One Column' => __('One Column','vw-wedding')
        ),
	) );
    
	//Slider
	$wp_customize->add_section( 'vw_wedding_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-wedding' ),
		'priority'   => null,
		'panel' => 'vw_wedding_panel_id'
	) );

	$wp_customize->add_setting( 'vw_wedding_search_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_wedding_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Wedding_Toggle_Switch_Custom_Control( $wp_customize, 'vw_wedding_search_hide_show',
       	array(
			'label' => esc_html__( 'Show / Hide Search','vw-wedding' ),
			'section' => 'vw_wedding_slidersettings'
    )));

	$wp_customize->add_setting( 'vw_wedding_slider_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_wedding_switch_sanitization'
    ));  
    $wp_customize->add_control( new VW_Wedding_Toggle_Switch_Custom_Control( $wp_customize, 'vw_wedding_slider_hide_show',
       	array(
		'label' => esc_html__( 'Show / Hide Slider','vw-wedding' ),
		'section' => 'vw_wedding_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_wedding_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'vw_wedding_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'vw_wedding_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-wedding' ),
			'description' => __('Slider image size (1500 x 665)','vw-wedding'),
			'section'  => 'vw_wedding_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting('vw_wedding_slider_button',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_wedding_slider_button',array(
		'label'	=> __('Slider Button text','vw-wedding'),
		'section'=> 'vw_wedding_slidersettings',
		'setting'=> 'vw_wedding_slider_button',
		'type'=> 'text'
	));

	//content layout
	$wp_customize->add_setting('vw_wedding_slider_content_option',array(
        'default' => __('Center','vw-wedding'),
        'sanitize_callback' => 'vw_wedding_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Wedding_Image_Radio_Control($wp_customize, 'vw_wedding_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','vw-wedding'),
        'section' => 'vw_wedding_slidersettings',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/slider-content1.png',
            'Center' => get_template_directory_uri().'/images/slider-content2.png',
            'Right' => get_template_directory_uri().'/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'vw_wedding_slider_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_wedding_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','vw-wedding' ),
		'section'     => 'vw_wedding_slidersettings',
		'type'        => 'range',
		'settings'    => 'vw_wedding_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('vw_wedding_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'vw_wedding_sanitize_choices'
	));

	$wp_customize->add_control( 'vw_wedding_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','vw-wedding' ),
	'section'     => 'vw_wedding_slidersettings',
	'type'        => 'select',
	'settings'    => 'vw_wedding_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','vw-wedding'),
      '0.1' =>  esc_attr('0.1','vw-wedding'),
      '0.2' =>  esc_attr('0.2','vw-wedding'),
      '0.3' =>  esc_attr('0.3','vw-wedding'),
      '0.4' =>  esc_attr('0.4','vw-wedding'),
      '0.5' =>  esc_attr('0.5','vw-wedding'),
      '0.6' =>  esc_attr('0.6','vw-wedding'),
      '0.7' =>  esc_attr('0.7','vw-wedding'),
      '0.8' =>  esc_attr('0.8','vw-wedding'),
      '0.9' =>  esc_attr('0.9','vw-wedding')
	),
	));

	// Bride & Groom
	$wp_customize->add_section('vw_wedding_bride_groom',array(
		'title'	=> __('Bride & Groom Section','vw-wedding'),
		'description'	=> __('Add Bride & Groom sections below.','vw-wedding'),
		'panel' => 'vw_wedding_panel_id',
	));

	$args =  array('numberposts' => 0);
	$post_list = get_posts($args);
	$i = 0;
	$pst[]='Select';  
	foreach($post_list as $post){
		$pst[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('vw_wedding_groom',array(
		'sanitize_callback' => 'vw_wedding_sanitize_choices',
	));
	$wp_customize->add_control('vw_wedding_groom',array(
		'type'    => 'select',
		'choices' => $pst,
		'label' => __('Select post','vw-wedding'),		
		'description' => __('Image size (171 x 146)','vw-wedding'),
		'section' => 'vw_wedding_bride_groom',
	));

	$args =  array('numberposts' => 0);
	$post_list = get_posts($args);
	$i = 0;
	$posts[]='Select';  
	foreach($post_list as $post){
		$posts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('vw_wedding_bride',array(
		'sanitize_callback' => 'vw_wedding_sanitize_choices',
	));
	$wp_customize->add_control('vw_wedding_bride',array(
		'type'    => 'select',
		'choices' => $posts,
		'label' => __('Select post','vw-wedding'),		
		'description' => __('Image size (171 x 146)','vw-wedding'),
		'section' => 'vw_wedding_bride_groom',
	));

	//Bride Groom excerpt
	$wp_customize->add_setting( 'vw_wedding_bride_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_wedding_bride_excerpt_number', array(
		'label'       => esc_html__( 'Bride Groom Excerpt length','vw-wedding' ),
		'section'     => 'vw_wedding_bride_groom',
		'type'        => 'range',
		'settings'    => 'vw_wedding_bride_excerpt_number',
		'input_attrs' => array(
			'step'             => 2,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	// Love Story
	$wp_customize->add_section('vw_wedding_love_story',array(
		'title'	=> __('Love Story Section','vw-wedding'),
		'description'	=> __('Add Love Story section below.','vw-wedding'),
		'panel' => 'vw_wedding_panel_id',
	));

	$args =  array('numberposts' => 0);
	$post_list = get_posts($args);
	$i = 0;
	$posts1[]='Select';  
	foreach($post_list as $post){
		$posts1[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('vw_wedding_love_story1',array(
		'sanitize_callback' => 'vw_wedding_sanitize_choices',
	));
	$wp_customize->add_control('vw_wedding_love_story1',array(
		'type'    => 'select',
		'choices' => $posts1,
		'label' => __('Select post','vw-wedding'),		
		'description' => __('Image size (417 x 270)','vw-wedding'),
		'section' => 'vw_wedding_love_story',
	));

	//Love Story excerpt
	$wp_customize->add_setting( 'vw_wedding_lovestory_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_wedding_lovestory_excerpt_number', array(
		'label'       => esc_html__( 'Love Story Excerpt length','vw-wedding' ),
		'section'     => 'vw_wedding_love_story',
		'type'        => 'range',
		'settings'    => 'vw_wedding_lovestory_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Blog Post
	$wp_customize->add_section('vw_wedding_blog_post',array(
		'title'	=> __('Blog Post Settings','vw-wedding'),
		'panel' => 'vw_wedding_panel_id',
	));	

	$wp_customize->add_setting( 'vw_wedding_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'vw_wedding_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Wedding_Toggle_Switch_Custom_Control( $wp_customize, 'vw_wedding_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','vw-wedding' ),
        'section' => 'vw_wedding_blog_post'
    )));

    $wp_customize->add_setting( 'vw_wedding_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_wedding_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Wedding_Toggle_Switch_Custom_Control( $wp_customize, 'vw_wedding_toggle_author',array(
		'label' => esc_html__( 'Author','vw-wedding' ),
		'section' => 'vw_wedding_blog_post'
    )));

    $wp_customize->add_setting( 'vw_wedding_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'vw_wedding_switch_sanitization'
    ) );
    $wp_customize->add_control( new VW_Wedding_Toggle_Switch_Custom_Control( $wp_customize, 'vw_wedding_toggle_comments',array(
		'label' => esc_html__( 'Comments','vw-wedding' ),
		'section' => 'vw_wedding_blog_post'
    )));

    $wp_customize->add_setting( 'vw_wedding_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'absint',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'vw_wedding_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','vw-wedding' ),
		'section'     => 'vw_wedding_blog_post',
		'type'        => 'range',
		'settings'    => 'vw_wedding_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Content Creation
	$wp_customize->add_section( 'vw_wedding_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'vw-wedding' ),
		'priority' => null,
		'panel' => 'vw_wedding_panel_id'
	) );

	$wp_customize->add_setting('vw_wedding_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new VW_Wedding_Content_Creation( $wp_customize, 'vw_wedding_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','vw-wedding' ),
		),
		'section' => 'vw_wedding_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'vw-wedding' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('vw_wedding_footer',array(
		'title'	=> __('Footer','vw-wedding'),
		'description'=> __('This section will appear in the footer','vw-wedding'),
		'panel' => 'vw_wedding_panel_id',
	));	
	
	$wp_customize->add_setting('vw_wedding_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_wedding_footer_text',array(
		'label'	=> __('Copyright Text','vw-wedding'),
		'section'=> 'vw_wedding_footer',
		'setting'=> 'vw_wedding_footer_text',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('vw_wedding_scroll_top_alignment',array(
        'default' => __('Right','vw-wedding'),
        'sanitize_callback' => 'vw_wedding_sanitize_choices'
	));
	$wp_customize->add_control(new VW_Wedding_Image_Radio_Control($wp_customize, 'vw_wedding_scroll_top_alignment', array(
        'type' => 'select',
        'label' => __('Scroll To Top','vw-wedding'),
        'section' => 'vw_wedding_footer',
        'settings' => 'vw_wedding_scroll_top_alignment',
        'choices' => array(
            'Left' => get_template_directory_uri().'/images/layout1.png',
            'Center' => get_template_directory_uri().'/images/layout2.png',
            'Right' => get_template_directory_uri().'/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'vw_wedding_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class VW_Wedding_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Wedding_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(new VW_Wedding_Customize_Section_Pro($manager,'example_1',array(
				'priority'   => 1,
				'title'    => esc_html__( 'Wedding Pro Theme', 'vw-wedding' ),
				'pro_text' => esc_html__( 'Upgrade Pro', 'vw-wedding' ),
				'pro_url'  => esc_url('https://www.vwthemes.com/themes/wordpress-wedding-theme/'),
			)));

		$manager->add_section(new VW_Wedding_Customize_Section_Pro($manager,'example_2',array(
				'priority'   => 1,
				'title'    => esc_html__( 'Documentation', 'vw-wedding' ),
				'pro_text' => esc_html__( 'Docs', 'vw-wedding' ),
				'pro_url'  => admin_url('themes.php?page=vw_wedding_guide'),
			)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-wedding-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-wedding-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
VW_Wedding_Customize::get_instance();